# Acknowledgements
Package management support is provided by NuGet, which is open-source software.

The original software is available from:
  http://nuget.codeplex.com/

This software is available under an Apache License v2.0:
  http://nuget.codeplex.com/license

Logging is provided by log4net, which is open-source software.

The original software is available from:
  http://logging.apache.org/log4net/

This software is available under an Apache License v2.0:
  http://logging.apache.org/log4net/license.html

Dependency injection is provided by Ninject, which is open-source software.

The original software is available from:
  http://www.ninject.org/

This software is available under an Apache License v2.0:
  https://github.com/ninject/ninject/blob/master/LICENSE.txt
